==> haskell-pointed-5.0.1-136-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pointed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pointed
version:              5.0.1
visibility:           public
id:                   pointed-5.0.1-79kHUrohe3PAVy3SLKa7d4
key:                  pointed-5.0.1-79kHUrohe3PAVy3SLKa7d4
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/pointed/
synopsis:             Pointed and copointed data
description:          Pointed and copointed data.
category:             Data
abi:                  b4e11047da7d8814e94a8f6007fa92c9
exposed:              True
exposed-modules:      Data.Copointed Data.Pointed
import-dirs:          /usr/lib/ghc-8.8.3/site-local/pointed-5.0.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/pointed-5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/pointed-5.0.1
hs-libraries:         HSpointed-5.0.1-79kHUrohe3PAVy3SLKa7d4
depends:
    base-4.13.0.0 comonad-5.0.6-9vmfn63yZ5TCVSvE579Krk
    containers-0.6.2.1
    data-default-class-0.1.2.0-3WblArvKItDIiwkDl9AciG
    hashable-1.2.7.0-BxGxAJSPpuh3YKsULesjmE
    kan-extensions-5.2-K3Y15uYebEwEkpmjRJQjxg
    semigroupoids-5.3.4-CwtgiZM8jOzphxkeUWb96 stm-2.5.0.0
    tagged-0.8.6-LfhHZ57rMjK9JkdnSRh9cF transformers-0.5.6.2
    transformers-compat-0.6.5-JSMUn8oEOEx4KSfZBSghWS
    unordered-containers-0.2.10.0-1E0nFKYS8XWLVv5PGwMT0V

haddock-interfaces:   /usr/share/doc/haskell-pointed/html/pointed.haddock
haddock-html:         /usr/share/doc/haskell-pointed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-pointed-5.0.1-137-x86_64.pkg.tar.zst: usr/share/haskell/register/haskell-pointed.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name:                 pointed
version:              5.0.1
visibility:           public
id:                   pointed-5.0.1-7BAzE7pI3YoHvyINzuxlFq
key:                  pointed-5.0.1-7BAzE7pI3YoHvyINzuxlFq
license:              BSD-3-Clause
copyright:            Copyright (C) 2008-2016 Edward A. Kmett
maintainer:           Edward A. Kmett <ekmett@gmail.com>
author:               Edward A. Kmett
stability:            provisional
homepage:             http://github.com/ekmett/pointed/
synopsis:             Pointed and copointed data
description:          Pointed and copointed data.
category:             Data
abi:                  581e724e36cd20c8cd84b0225fa039e7
exposed:              True
exposed-modules:      Data.Copointed Data.Pointed
import-dirs:          /usr/lib/ghc-8.8.3/site-local/pointed-5.0.1
library-dirs:         /usr/lib/ghc-8.8.3/site-local/pointed-5.0.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/x86_64-linux-ghc-8.8.3/pointed-5.0.1
hs-libraries:         HSpointed-5.0.1-7BAzE7pI3YoHvyINzuxlFq
depends:
    base-4.13.0.0 comonad-5.0.6-9vmfn63yZ5TCVSvE579Krk
    containers-0.6.2.1
    data-default-class-0.1.2.0-3WblArvKItDIiwkDl9AciG
    hashable-1.2.7.0-BxGxAJSPpuh3YKsULesjmE
    kan-extensions-5.2-L9ilzwCQl3755Qn3b3byrk
    semigroupoids-5.3.4-AKGKL2lrjmi1GbOLdy8tuN stm-2.5.0.0
    tagged-0.8.6-LfhHZ57rMjK9JkdnSRh9cF transformers-0.5.6.2
    transformers-compat-0.6.5-JSMUn8oEOEx4KSfZBSghWS
    unordered-containers-0.2.10.0-1E0nFKYS8XWLVv5PGwMT0V

haddock-interfaces:   /usr/share/doc/haskell-pointed/html/pointed.haddock
haddock-html:         /usr/share/doc/haskell-pointed/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
